.. FLAML documentation master file, created by
   sphinx-quickstart on Mon Dec 14 23:33:24 2020.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. Welcome to FLAML's documentation!
.. =================================

.. .. toctree::
..    :maxdepth: 2
..    :caption: Contents:


FLAML API Documentation
=======================

AutoML
------

.. autoclass:: flaml.AutoML
   :members:


Tune
----

.. autofunction:: flaml.tune.run

.. autofunction:: flaml.tune.report

.. autoclass:: flaml.BlendSearch
   :members:

.. autoclass:: flaml.CFO
   :members:

.. autoclass:: flaml.FLOW2
   :members:


Online AutoML
-------------

.. autoclass:: flaml.AutoVW
   :members:


NLP
---

.. autoclass:: flaml.nlp.AutoTransformers
   :members:

.. autoclass:: flaml.nlp.AzureUtils
   :members:

.. autoclass:: flaml.nlp.JobID
   :members:


.. Indices and tables
.. ==================

.. * :ref:`genindex`
.. * :ref:`modindex`
.. * :ref:`search`
